MAIN_PAGE_NAME   = "Ninja Gaiden 2/main.html"
TITLE_PAGE_NAME  = "Ninja Gaiden 2/title.html"
MAX_STAGES = 7
SCREEN_SIZE_SCALE = 3.214285714285714 -- the emu screen and the sidebar screen area aren't the same size, so we need this for conversion

totalDeaths = 0
levNum = -1
lastLevNum = -1
currStage = -2
lastStage = -2
gameHasStarted = false

stageDeaths = {}

-- ==============================================================================================
-- INTERNAL VARIABLES FOR MISC USE
-- ==============================================================================================



-- ==============================================================================================
-- ==============================================================================================
-- This runs once before doLogic ever runs
function init()
	--loadHTML(TITLE_PAGE_NAME)
	resize(1200, 720)
	loadHTML(MAIN_PAGE_NAME)
	callJSFunction("clearAllData")
	
	stageDeaths = {-1, -1, -1, -1, -1, -1, -1}
	currStage = -2
	lastStage = -2
	gameHasStarted = false
end


-- ==============================================================================================
-- ==============================================================================================
-- This handles messages sent by the emulator, like if the player presses certain buttons or
-- other events happen within the emulator itself
function getMessage(str)
	if str == "resetgame" then
		init()
	elseif str == "loadstate" then
		loadHTML(MAIN_PAGE_NAME)
		callJSFunction("clearAllData")
	end
end


-- ==============================================================================================
-- ==============================================================================================
-- All main logic goes in here & gets called once per CPU cycle
function doLogic()
	
	levNum = getMemory(0x7E, 1)
	
	currStage = ConvertLevelNumToStageNum(levNum)
	if currStage ~= lastStage and currStage > 0 and currStage <= MAX_STAGES then
		if stageDeaths[currStage] == -1 then
			stageDeaths[currStage] = 0
			updateStageDeathList()
		end
	end
	
	if levNum ~= lastLevNum then
		if levNum == 0x03 then
			callJSFunction_Str("drawBossName", "Dando the Cursed")
		elseif levNum == 0x08 then
			callJSFunction_Str("drawBossName", "Baron Spider")
		elseif levNum == 0x0F then
			callJSFunction_Str("drawBossName", "Funky Dynamite")
		elseif levNum == 0x16 then
			callJSFunction_Str("drawBossName", "Naga Sotuva")
		elseif levNum == 0x1D then
			callJSFunction_Str("drawBossName", "Ashtar")
		elseif levNum == 0x22 then
			callJSFunction_Str("drawBossName", "Kelbeross")
		elseif levNum == 0x2D then
			callJSFunction_Str("drawBossName", "Jaquio")
		elseif levNum == 0x2E then
			callJSFunction_Str("drawBossName", "True Jaquio")
		elseif levNum == 0x2F then
			callJSFunction_Str("drawBossName", "Jaquio Unleashed")
		end
	end

	lastLevNum = levNum
	lastStage = currStage
end





--[=====[ 
frameCount = 0
lastDisplayItem = { 0, 0, 0, 0, 0, 0, 0, 0 }
function doLogicFrame()

	gameMode = getMemory(0x1DD, 1)
	if gameMode == 0xF and frameCount % 60 == 0 then -- if we're playing the main game
		
		itemDisplayFlags = getMemory(0xD8, 1)
		for i=0,7 do
		
			displayItem = itemDisplayFlags & (1 << i)

			index = i
			if i >= 4 then
				index = i - 4
			end

			if displayItem ~= 0x00 then -- see if this item slot is active

				itemX = getMemory(0x554 + index, 1)
				itemY = getMemory(0x584 + index, 1)
				itemType = getMemory(0x524 + index, 1)
				itemUsed = getMemory(0x4F4 + index, 1)

				x = math.floor(itemX * SCREEN_SIZE_SCALE)
				y = math.floor(itemY * SCREEN_SIZE_SCALE)

				if (itemType & 0xF0) == 0x0 and itemY < 0xD0 and itemUsed == 0x0 then
					callJSFunction_Int2("moveItemX", i, x)
					callJSFunction_Int2("moveItemY", i, y)
					
					if displayItem ~= lastDisplayItem[i + 1] then
						--callJSFunction_Int2("showItem", i, 1)
					end
				else
					if displayItem ~= lastDisplayItem[i + 1] then
						--callJSFunction_Int2("showItem", i, 0)
					end
				end
			end
			
			lastDisplayItem[i + 1] = displayItem
		end

	end

	
	frameCount = frameCount + 1
end
--]=====]




-- ==================================================================================================
-- MAIN LOGIC (SCRIPT DISPLAYING, ETC.)
-- ==================================================================================================



-- GAME IS BEING STARTED, FIRST LEVEL ABOUT TO LOAD
function PC_96BB()
	if getBank() == 0x02 and gameHasStarted == false then
		callJSFunction("startMainTimer")
		gameHasStarted = true
	end
end




-- LIVES ARE BEING DECREASED
--function PC_C8A2()
-- CHARACTER JUST DIED
function PC_C865()
	if getBank() == 0x07 then
		if currStage > 0 and currStage <= MAX_STAGES then
			stageDeaths[currStage] = stageDeaths[currStage] + 1
		end
		
		
	
		totalDeaths = totalDeaths + 1
		updateStageDeathList()
		
		drawEnemyMessages()
	end
end



function updateStageDeathList()
	str = "<table id=\"stage-deaths\">"
	
	for i=1,MAX_STAGES do
		
		if stageDeaths[i] >= 0 then
			blinkClass = ""
			if i == currStage and stageDeaths[i] > 0 then
				blinkClass = " class=\"blink\""
			end
		
			str = str .. "<tr" .. blinkClass .. "><td>Stage " .. i .. ":</td><td>" .. stageDeaths[i] .. "</td></tr>"
		end
		
	end
	
	str = str .. "</table>"
	
	writeHTML("deathlist", str)
	writeHTML("totaldeathcount", totalDeaths)
end











function AddDeathToStage(stage)
end

        
function ConvertLevelNumToStageNum(levelNum)
	retVal = -1
    
	if levelNum >= 0x00 and levelNum <= 0x03 then
		retVal = 1
    elseif levelNum >= 0x04 and levelNum <= 0x08 then
		retVal = 2
	elseif levelNum >= 0x09 and levelNum <= 0x0F then
		retVal = 3
	elseif levelNum >= 0x10 and levelNum <= 0x16 then
		retVal = 4
	elseif levelNum >= 0x17 and levelNum <= 0x1D then
		retVal = 5
	elseif levelNum >= 0x1E and levelNum <= 0x22 then
		retVal = 6
	elseif levelNum >= 0x23 and levelNum <= 0x2D then
		retVal = 7
	end

	return retVal
end


function isLivingEnemy(i) -- determines if an enemy code is a living being or a projectile thingy
	retVal = true

	if i == 0x1C then -- ninja star
		retVal = false
	elseif i == 0x3A then -- rocket launcher rockets
		retVal = false
	elseif i == 0x3F then -- blob bullets
		retVal = false
	elseif i == 0x45 then -- spider bullet
		retVal = false
	elseif i == 0x4C then -- rock thrown by buff guy
		retVal = false
	elseif i == 0x4D then -- wind
		retVal = false
	elseif i == 0x5C then -- downward daggers
		retVal = false
	end

	return retVal
end




function drawEnemyMessages()
	yDiff = 0
    enDisplay = getMemory(0x4A, 1)
	
    for i = 0, 7 do
		enIndex = 7 - i
        enemyShow = enDisplay & (1 << enIndex)
        if enemyShow ~= 0 then
			enemyID = getMemory(0x400 + i, 1)
			enX = getMemory(0x567 - i, 1)
			enY = getMemory(0x597 - i, 1)
			
			spriteID = getMemory(0x477 - i, 1)
			if isLivingEnemy(spriteID) then

				x = enX * SCREEN_SIZE_SCALE - 64
                y = enY * SCREEN_SIZE_SCALE

				y = y - 110
                y = y - yDiff
				
				callJSFunction_Int2("drawMessage", math.floor(x), math.floor(y))
				callJSFunction_Int("clearMessagesTimer", 2000)

                yDiff = yDiff + 58
			end
		end



    end
end