// *********************************************************************************
// ESSENTIAL INTERNAL ROUTINES
// *********************************************************************************

// =================================================================================
// 
// =================================================================================
function replaceHtml(el, html) {
	var oldEl = typeof el === "string" ? document.getElementById(el) : el;
	var newEl = oldEl.cloneNode(false);
	newEl.innerHTML = html;
	oldEl.parentNode.replaceChild(newEl, oldEl);
	return newEl;
};


function writeHTML(id, msg)
{
	replaceHtml(id, msg);
}
	

// =================================================================================
// Copy the contents of one HTML element into another
// The destination's previous contents are overwritten
// =================================================================================
function copyHTMLElement(source, destination)
{
	$(destination).html($(source).html());
}


// =================================================================================
// Move the contents of one HTML element into another
// The source's current contents are removed
// The destination's previous contents are overwritten
// =================================================================================
function moveHTMLElement(source, destination)
{
	$(destination).html($(source).detach().html());
	//$(source).appendTo(destination);
	/*var s = $(source);
	var h = s.html();
	s.empty();
	$(destination).html(h);*/
	//$(source).detach().html(destination);
	//$(destination).show()
}


// =================================================================================
// Append content of source div to content of destination div
// Since this uses jQuery, IDs need to use #
// The copied HTML content is wrapped in a div for convenience purposes
// =================================================================================
function appendHTMLElement(source, destination)
{
	$(destination).append("<div class=\"" + $(source).attr("id") + "\">" + $(source).html() + "</div>");
}


// *********************************************************************************
// GAME-SPECIFIC ROUTINES
// *********************************************************************************


var audio = new Audio('voom.wav');



// =================================================================================
// A super-helpful way to clear the main viewing area of all text
// =================================================================================

function clearAllData()
{
	$("#container > div").html("");
	$("#container > div").show();
}

var origDate;
var mainTimer;
function startMainTimer()
{
    origDate = Date.now();
    mainTimer = setInterval( function(){
        $("#time").html(getElapsedTimeString());
    }, 10);
	
	audio.play();
}

function stopMainTimer()
{
	clearInterval(mainTimer);
}




function getElapsedTimeString()
{
	var currDate = Date.now();
	var diff = currDate - origDate;
	
	var temp = diff;
	var milliseconds = Math.floor(temp % 1000);
	temp /= 1000;
	var seconds = Math.floor(temp % 60);
	temp /= 60;
	var minutes = Math.floor(temp % 60);
	temp /= 60;
	var hours = Math.floor(temp % 24);
	temp /= 24;
	var days = Math.floor(temp);

	daysStr = pad(days, 2) + ":";
	hoursStr = pad(hours, 2) + ":";
	minutesStr = pad(minutes, 2) + ":";
	secondsStr = pad(seconds, 2) + ".";
	
	temp = milliseconds / 10;
	millisecondsStr = pad(temp.toFixed(0), 2);
		
	str = "";
	if (days <= 0)
	{
		daysStr = "";
	}
	
	str = daysStr + hoursStr + minutesStr + secondsStr + millisecondsStr;
	return str;
}

function pad(n, width, z) {
  z = z || '0';
  n = n + '';
  return n.length >= width ? n : new Array(width - n.length + 1).join(z) + n;
}



function drawMessage(x, y)
{
	str = deathQuotes[Math.floor(Math.random() * deathQuotes.length)];
	$("#screen-area").append("<div class=\"screen-message\" style=\"top:" + y + "px;left:" + x + "px;\">" + str + "</div>");
}

function drawBossName(str)
{
	setTimeout(function() {
		$("#screen-area").html("<div class=\"boss-name\"><div class=\"name\">" + str + "</div></div>");
		clearMessagesTimer(9000);
	}, 1500);
}


function clearAllMessages()
{
	$("#screen-area .screen-message").remove();
	$("#screen-area .name").remove();
}

var clearMsgTimer;
function clearMessagesTimer(t)
{
	clearTimeout(clearMsgTimer);
	setTimeout(clearAllMessages, t);
}






function moveItemX(item, x)
{
	$("#item" + item).css("left", x);
}

function moveItemY(item, y)
{
	$("#item" + item).css("top", y);
}

function showItem(item, display)
{
	if (display)
	{
		$("#item" + item).show();
	}
	else
	{
		$("#item" + item).hide();
	}
}