-- ==============================================================================
-- SIDEBAR LOGIC - INTERNAL FUNCTIONS
-- BY Clyde Mandelin
--
-- The following functions are used by the sidebar's C++ programming as a way
-- to access Lua scripts in ways that shouldn't be used by the ordinary user.
-- These are in a separate file for ease of use and so that users' scripts will
-- appear as simple and clean as possible.
-- ==============================================================================


-- ==============================================================================
-- Collects all global functions starting with PC_ followed by a hex CPU address
-- Used by the sidebar for quick access to CPU address-specific breakpoints
-- ==============================================================================
function detectPCBreakpoints()
  local breakpoints = { }

  for k,v in pairs(_G) do
	local p1 = string.match(k, "^PC_(%x.*)")
	if p1 ~= nil then
		breakpoints[#breakpoints + 1] = tonumber(p1, 16)
	end
  end

  return breakpoints
end